-- 登录公告
Lua_AnnouncementWindow = class("Lua_AnnouncementWindow", Lua_Window);
function Lua_AnnouncementWindow:ctor()
    self:superCall("ctor");

    self.windowName = "Lua_AnnouncementWindow";
    self.skinName = "AnnouncementWindow_skin";
    self.w = 676;
    self.h = 824;
    self.showBlackMask = true;
    self.showClose = true;
    self.isClickClose = true;
end

function Lua_AnnouncementWindow:buildShowItem()
    self:superCall("buildShowItem");

    self.btnClose:setLocation(295, 365, 0);

    self.dragContainer = Lua_DragContainer.new(self.content, 560, 580, Lua_AxisDefine.Vertical);
    self.dragContainer:setLocation(0, -10, 0);
    self.dragContainer:addSubContainer(Lua_AnnouncementItem);

    self.sureBtn:addClickFuntion(self, self.hide);
end

function Lua_AnnouncementWindow:dispose()
    if self.dragContainer ~= nil then
        self.dragContainer:dispose();
        self.dragContainer = nil;
    end
    
    UploadManager.getInstance():clearRequest(UrlManager.prefixRequestReportUrl, self, nil);
    self:superCall("dispose");
end

function Lua_AnnouncementWindow:showWin(param)
    self:superCall("showWin", param);
    if param ~= nil then
        self:updateData(param);
        return;
    end

    local formData = {
        func = "notice",
        package = ServerConfig.market
    };
    local tokenstr = decodeTabToJson(formData);
    UploadManager.getInstance():uploadPhpPost(UrlManager.prefixRequestReportUrl, tokenstr, self, self.loadAnnouncementComplete, self.loadAnnouncementErr, true);
end

function Lua_AnnouncementWindow:loadAnnouncementComplete(text)
    if LanUtil.IsNullOrEmpty(text) then
        self:hide();
        return;
    end

    local obj = decodeJson(text);
    DataCenter.loginData.announcementObj = obj;
    if obj == nil then
        self:hide();
        return;
    end

    self:updateData(obj);
end

function Lua_AnnouncementWindow:loadAnnouncementErr(text)
    print("公告报错");
    self:hide();
end

function Lua_AnnouncementWindow:updateData(val)
    if val ~= nil then
        if val.title ~= nil and val.content ~= nil then
            self.updateContentTx.text = val.title;
            self.dragContainer:setChildData(val);
        else
            self:hide();
        end
    else
        self:hide();
    end
end





--------------------------------------------------





Lua_AnnouncementItem = class("Lua_AnnouncementItem", Lua_DragContainerItem);
function Lua_AnnouncementItem:ctor(sub)
    self:superCall("ctor", sub);
end

function Lua_AnnouncementItem:buildShowItem()
    self:superCall("buildShowItem");

    self.label = UICreate.createLabel(self.content, "", 0, 0, 560, 0, 22);
    self.label.verticalOverflowValue = 1;
    self.label.lineSpacing = 1;
    self.label.name = "label";

    self.timeTxt = UICreate.createLabel(self.content, "", 0, 0, 560, 0, 22);
    self.timeTxt.alignmentValue = 5;
    self.timeTxt.verticalOverflowValue = 1;
    self.timeTxt.name = "timeTxt";
end

function Lua_AnnouncementItem:dispose()
    if self.label ~= nil then
        self.label:dispose();
        self.label = nil;
    end
    if self.timeTxt ~= nil then
        self.timeTxt:dispose();
        self.timeTxt = nil;
    end
    if self.imgShowArr ~= nil then
        self.imgShowArr:dispose();
        self.imgShowArr:clear();
        self.imgShowArr = nil;
    end
    if self.imgHideArr ~= nil then
        self.imgHideArr:dispose();
        self.imgHideArr:clear();
        self.imgHideArr = nil;
    end
    self:superCall("dispose");
end

function Lua_AnnouncementItem:setData(data)
    self.data = data;
    local arr = self:splitStr(data.content, "<img>");
    local showStr = "";
    for i = 1, arr:getSize() do
        local tab = self:stringToTable(arr[i]);
        if tab ~= nil and tab.url ~= nil and tab.w ~= nil and tab.h ~= nil then
            showStr = spliceImgStr(tab.url, tab.w, tab.h);
        else
            showStr = showStr .. arr[i];
        end
        self.label.text = showStr;
    end

    if data.time ~= nil then
        self.timeTxt:setLocation(0, -self.label.height, 0);
        self.timeTxt.text = "<color=#4A6793>" .. tostring(os.date("%Y%m%d", data.time)) .. "</color>";
    end

    self.label:resetSize()
    self.timeTxt:resetSize()
end

function Lua_AnnouncementItem:splitStr(str, reps)
    local arr = Array();
    local showStr = str;
    local len = string.len(showStr);
    local startIndex, endIndex = string.find(showStr, reps);
    while(startIndex ~= nil) do
        if startIndex ~= 1 then
            arr:add(string.sub(showStr, 1, startIndex - 1));
        end
        if endIndex == len then break end;

        showStr = string.sub(showStr, endIndex + 1);
        startIndex, endIndex = string.find(showStr, reps);
    end
    arr:add(showStr);
    return arr;
end

function Lua_AnnouncementItem:stringToTable(str)
    local func = loadstring("return " .. str);
    local tab = nil;
    if func ~= nil then
        tab = func();
    end
    return tab;
end  

-- function Lua_AnnouncementItem:addSpaceHeight(imgHeight)
--     local lineHeight = 31;
--     local addNum = Mathf.Ceil(tostring(imgHeight / lineHeight));
--     local str = "";
--     for i = 1, addNum do
--         str = str .. "\n";
--     end
--     return str;
-- end

-- function Lua_AnnouncementItem:createImgItem()
--     if self.imgShowArr == nil then
--         self.imgShowArr = Array();
--     end
--     if self.imgHideArr == nil then
--         self.imgHideArr = Array();
--     end

--     local item;
--     if self.imgHideArr:getSize() > 0 then
--         item = self.imgHideArr:shift();
--         item:setEnable(true);
--     else
--         item = UICreate.createImage(self.content, "", 0, 0, 0, 0);
--     end
--     self.imgShowArr:add(item);
--     return item;
-- end

-- function Lua_AnnouncementItem:returnImgPool()
--     if self.imgShowArr ~= nil then
--         for i = 1, self.imgShowArr:getSize() do
--             local item = self.imgShowArr:shift();
--             item:SetDimensions(1, 1);
--             item:setEnable(false);
--             self.imgHideArr:add(item);
--         end
--     end
-- end

function Lua_AnnouncementItem:getWidth()
    return self.label.width;
end

function Lua_AnnouncementItem:getHeight()
    return self.label.height;
end
