-- 登录选服界面
Lua_ServerSelectWindow = class("Lua_ServerSelectWindow", Lua_Window);
function Lua_ServerSelectWindow:ctor()
    self:superCall("ctor");
    
    self.windowName = "Lua_ServerSelectWindow";
    self.skinName = "ServerSelectWindow_skin";
    self.isFullSizeWin = true;
    self.openSound = "";
    self.closeSound = "";

    self.lastTime = -10;
    self._bLoadServerList = false;
    self.protocolNum = 0;
end

function Lua_ServerSelectWindow:dispose()
    UploadManager.getInstance():clearRequest(UrlManager.prefixRequestLoginStr, self, nil);
    self:superCall("dispose");
    if self.serverItem ~= nil then
        self.serverItem:dispose();
        self.serverItem = nil;
    end
    
    if self.serverData ~= nil then
        self.serverData:clean();
        self.serverData = nil;
    end
end

function Lua_ServerSelectWindow:buildShowItem()
    self:superCall("buildShowItem");
    -- 版署：屏蔽功能按钮
    self.annIcon:setEnable(false);
    self.repairIcon:setLocation(-287, -182);
    
    GlobalVar.isInGame = 0;

    self.protocolNum = PlayerPrefsUtil.instance:GetInt(SetUpDefine.PROTOCOL, 1);
    DataCenter.gameReported:loginReportedData(Lua_GameReported.ENTER_SERVERSELECT_WIN);
    
    -- 用户协议
    if ServerConfig.isSecret then
        self.cBox:setEnable(true);
        self.cBox:addBoxChange(self, self.onChangeBox);--游戏协议
        self.cBox.selected = self.protocolNum == 1;

        self.protocolTxt:setEnable(true);
        self.protocolTxt:setLangValue(123704);
        self.protocolTxt:addUrlClickFuntion(self, self.onProtocolClick);
    else
        self.cBox:setEnable(false);
        self.protocolTxt:setEnable(false);
    end

    -- 显示著作权信息
    if ServerConfig.bShowZhuzuoInfo then
        self.tipsTtile:setLangValue(123702);
        self.tipsDes:setLangValue(123703);
    else--健康公告
        self.tipsTtile:setLangValue(123700);
        self.tipsDes:setLangValue(123701);
    end
    
    MsgUtil.callFunc("LOGIN_BG_CHANGE", "/images/loading/login_bg.jpg");

    self.btnBack:setEnable(false);
    if SDKInfo.IsNoSdk then
        self.btnBack:setEnable(true);
        self.btnBack:addClickFuntion(self, self.onBackClick);
    end
    self.annIcon:addClickFuntion(self, self.onAnnClick);--公告
    self.enterIcon:addClickFuntion(self, self.onEnterClick);--进入游戏
    self.repairIcon:addClickFuntion(self, self.onRepairClick);--修复工具处理
    self.serverNameBg:addClickFuntion(self, self.onServerNameClick);--服务器选择

    self:addCSharpEvent("SERVER_SELECT_BACK", self, self.onServerSelectBack);
    self:addLuaEvent("SELECTE_SERVER", self, self.updateSelectedServer);--更新选择的服务器

    Lua_WindowUtil.openWin("Lua_LoadingScreenWindow", Lua_WinParam.ACTION_CLOSE);
    Lua_WindowUtil.openWin("Lua_StartWindow", Lua_WinParam.ACTION_CLOSE);
    Lua_WindowUtil.openWin("Lua_LoginWindow", Lua_WinParam.ACTION_CLOSE);
    -- Lua_WindowUtil.openWin("Lua_LoginPhoneWindow", Lua_WinParam.ACTION_CLOSE);

    -- 获取服务器列表
    if Lua_WindowUtil.getWinListData(self.windowName, false) == nil then
    	Lua_MsgUtil.callFunc("LOGIN_BACK_SEVER_SELECTED");
    end
end

function Lua_ServerSelectWindow:showWin(param)
    self:superCall("showWin", param);

    if param ~= nil then
        self._bLoadServerList = true;
        if self.serverData ~= nil then
            self.serverData:clean();
            self.serverData = nil;
        end

        self.serverData = param;
        self:updateSelectedServer(self.serverData:getDefaultServer());
        self:loadAnnouncement(); -- 有公告则显示公告
    elseif not self._bLoadServerList then
        Lua_MsgUtil.callFunc("LOGIN_BACK_SEVER_SELECTED");
    end
end

function Lua_ServerSelectWindow:onChangeBox(val)
    self.cBox.selected = val;
    self.protocolNum = val and 1 or 0;
    PlayerPrefsUtil.instance:SetInt(SetUpDefine.PROTOCOL, self.protocolNum);
end

function Lua_ServerSelectWindow:onProtocolClick(urlStr)
    local t = getTime();
    if t - self.lastTime < 1 then
        return;
    end

    self.lastTime = t;
    if not LanUtil.IsNullOrEmpty(urlStr) then
    	if Lua_PlatformUtil.IsAndroid() or Lua_PlatformUtil.IsIPhonePlayer() then
    		local formData = {};
	        if urlStr == "user_protocol" then
	        	formData.title = LanUtil.getValue(123708);
	        	formData.url = ServerConfig.protocolUrl;
	        else
	        	formData.title = LanUtil.getValue(123709);
	        	formData.url = ServerConfig.privacyUrl;
	        end

	        local jsonStr = decodeTabToJson(formData);
	        print("webActivity jsonStr = ", jsonStr);
            DataCenter.sdkInterface:callSDKInterface(Lua_SDKMessageType.WebActivity, jsonStr);
		else
	        if urlStr == "user_protocol" then
	            print("OpenURL: ", ServerConfig.protocolUrl);
	            if not LanUtil.IsNullOrEmpty(ServerConfig.protocolUrl) then
	                Application.OpenURL(ServerConfig.protocolUrl);
	            end
	        else
	            print("OpenURL: ", ServerConfig.privacyUrl);
	            if not LanUtil.IsNullOrEmpty(ServerConfig.privacyUrl) then
	                Application.OpenURL(ServerConfig.privacyUrl);
	            end
	        end
		end
    end
end

function Lua_ServerSelectWindow:loadAnnouncement()
    if PlayerData.instance.phpData.bTishenServer then
        return;
    end
    Lua_MsgUtil.callFunc("GetAnnouncementServerInfo", false);
end

-- 更新选择的服务器
function Lua_ServerSelectWindow:updateSelectedServer(data)
	-- print("Lua_ServerSelectWindow updateSelectedServer", data == nil);
    if data == nil then
        self.signBg:setEnable(false);
        self.stateTxt.text = "";
        self.serverNameTxt.text = "";
    else
        local str;
        local status = data.status;
        if status == -1 then --维护
            str = LanUtil.getValue(123707);
        elseif status == 2 then --流畅
            str = LanUtil.getValue(123706);
        elseif status == 4 then --爆满
            str = LanUtil.getValue(123705);
        else
            --流畅
            str = LanUtil.getValue(123706);
        end
        self.stateTxt.text = str;
        self.serverNameTxt.text = data.name;

        if data.ad_status == 1 or data.ad_status == 2 then--新区/推荐
            self.signBg:setEnable(true);
        else
            self.signBg:setEnable(false);
        end
    end
    self.serverData.selectServerData = data;
end

function Lua_ServerSelectWindow:onServerSelectBack()
    self:onBackClick();
end

function Lua_ServerSelectWindow:onEnterClick()
    if self.serverData == nil then
        return;
    end

    if self.protocolNum == 0 and ServerConfig.isSecret then
        OperateAlert.showLangValue(123710);
        return;
    end

    local t = getTime();
    if t - self.lastTime < 1 then
        OperateAlert.showLangValue(123711);
        return;
    end
    self.lastTime = t;

    if self.serverData.isBan then
        OperateAlert.showLangValue(123712);
        return;
    end

    local selectedServer = self.serverData.selectServerData;
    if selectedServer == nil then
        OperateAlert.showLangValue(123713);
        return;
    end

    if selectedServer.is_create_role == 0 and selectedServer.is_account_create == 0 then --账号创建角色达到上限
        OperateAlert.showLangValue(123714);
        return;
    end

    if selectedServer.is_create == 0 then
        OperateAlert.showLangValue(123715);
        return;
    end

    if selectedServer.status == -1 then
        local str = LanUtil.getValue(123716);
        if selectedServer.text ~= nil and selectedServer.text ~= "" then
            str = selectedServer.text;
        end

        local tipsData = {};
		tipsData.des = str; --文本描述
		tipsData.btnType = 4;
		tipsData.sureLabel = LanUtil.getValue(123717);
		Lua_WindowUtil.openWin("Lua_LoginTipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
        OperateAlert.showLangValue(123718);
        return;
    elseif selectedServer.status == 0 then
    	local tipsData = {};
		tipsData.des = selectedServer.text; --文本描述
		tipsData.btnType = 4;
		tipsData.sureLabel = LanUtil.getValue(123717);
		Lua_WindowUtil.openWin("Lua_LoginTipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
        return;
    end

    PlayerPrefsUtil.instance:SetString(SetUpDefine.SELECT_SERVER, selectedServer.flag);
    local max = selectedServer.max_online;
    if selectedServer.online >= max and max ~= 0 then
    	local tipsData = {};
		tipsData.des = LanUtil.getValue(123719); --文本描述
		tipsData.btnType = 4;
		tipsData.sureLabel = LanUtil.getValue(123717);
		Lua_WindowUtil.openWin("Lua_LoginTipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
        return;
    end

    Lua_MsgUtil.callFunc("SERVER_VALISOCKET_CONNECT", selectedServer);
end

function Lua_ServerSelectWindow:onServerNameClick(go)
    if self.serverData == nil then
        return;
    end
    Lua_WindowUtil.openWin("Lua_ServerListWindow", Lua_WinParam.ACTION_OPEN, self.serverData);
end

function Lua_ServerSelectWindow:onAnnClick(go)
    Lua_MsgUtil.callFunc("GetAnnouncementServerInfo", true);
end

function Lua_ServerSelectWindow:onBackClick(go)
    LuaUtil.relogin();
end

function Lua_ServerSelectWindow:onRepairClick(go)
    --修复工具处理
    local tipsData = {};
    tipsData.des = LanUtil.getValue(380029); --文本描述
    tipsData.btnType = 1;
    tipsData.owner = self;
    tipsData.sureFun = self.onRepairSure;
    Lua_WindowUtil.openWin("Lua_LoginTipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
end

function Lua_ServerSelectWindow:onRepairSure()
    LuaUtil.repairUpdateData();
end