-- 登录数据
Lua_LoginData = class("Lua_LoginData");
function Lua_LoginData:ctor()
	self:superCall("ctor");
	self:init()
end

function Lua_LoginData:init()
    self.isCreateRole = false; -- 是否已创角
    self.bAutoCreateRole = false; -- 是否自动创建
    self.bLoadingVideoType = false; -- 是否视频加载进度
    self.bShowVideoFrame = true; -- 如果是创角，是否显示视频第一帧
    self.bPreLoadComplete = false; -- 预加载完成
    self.openServerDays = 0; -- 开服天数
    self.createRoleDays = 0; -- 创号天数

    self.waitShowScene = nil;
    self.waitInitedWinName = nil;
    self.bStartLoadEnterGame = false;
    self.isUpdatePlayerInfo = false;
    self.videoSign = "LOGINLOADING";

    self.isInGame = false

    self.stopAllGuide = true; -- 引导开关
end

function Lua_LoginData:dispose()
    Lua_CommonUtil.removeTimer(self, self.checkHeartUpdate)
    self:clearChcekVideo();
    self:clearHeart()
    self:init()
end

-- 检测角色名是否无效
function Lua_LoginData:checkRoleNameIsInvalid(str)
    local nameLen = stringWidth(str)
	if nameLen <= 0 then
		OperateAlert.showLangValue(123724);
		return true;
	end

    local nameLimit = Lua_CommonUtil.getCommonConfig("name_character_limit", 3)
    if nameLen < nameLimit[1] / 2 then
        OperateAlert.showLangValue(123731);
        return true
    end

	if nameLen > nameLimit[2] / 2 then
		OperateAlert.showLangValue(123725);
		return true;
	end

	-- 包含敏感字或空格
	if FilterText.GetInstance():IsInvalid(str, true, 0) or FilterText.GetInstance():IsInvalid(str, true, 1) then
		OperateAlert.showLangValue(123726);
		return true;
	end

	local si, ei = string.find(str, "\\");
	if si ~= nil and si > 0 then
		OperateAlert.showLangValue(123726);
		return true;
	end

	-- 数字或者字母太多
	if LanUtil.checkStrNumberCount(str) >= 7 or LanUtil.checkStrEngAlphabetCount(str) >= 5 then
		OperateAlert.showLangValue(123727);
		return true;
	end

	return false;
end

function Lua_LoginData:onInit()
	CameraControl.Instance:init();
    DataCenter.gameReported:loginReportedData(Lua_GameReported.ENTER_GAME_SCENE);
    if Lua_PlatformUtil.IsWindowsEditor() then
    	LuaUtil.showFps(true);
    end
end

-- 心跳
function Lua_LoginData:addHeart()
    if self.bAddHeartTimer ~= true then
        self.bAddHeartTimer = true;
        Lua_CommonUtil.addTimer("onHeart", 5, self, self.onHeart);
    end
end

function Lua_LoginData.Get:connectManager()
    if self._connectManager == nil then
        self._connectManager = ConnectionManager.getInstace();
    end
    return self._connectManager;
end

function Lua_LoginData:onHeart(dt)
    if self.connectManager:isConnection(Connection.MAIN_SOCKET) then
        sendMsg(10100006);
    end
end

function Lua_LoginData:clearHeart()
    if self.bAddHeartTimer == true then
        self.bAddHeartTimer = false;
        Lua_CommonUtil.removeTimer(self, self.onHeart);
    end
end

-- 游戏后台状态切换
function Lua_LoginData:updateRunStateChange(stateVal)
    Lua_CommonUtil.removeTimer(self, self.checkHeartUpdate);
    if stateVal == 0 then
        if self.connectManager:isConnection(Connection.MAIN_SOCKET) ~= true then
            GlobalVar.canReconnect = true;
            self.connectManager:errorAlert(LanUtil.getValue(10003), true);
            print("断线重连 serverprox.onRunInBackgroundChange");
        else
            self:onHeart();
            Lua_CommonUtil.delayCall(2, self, self.checkHeartUpdate); -- 长时间未通信，服务端TCP断开，心跳未返回的情况
        end
    else
        self:onHeart();
    end
end

function Lua_LoginData:checkHeartUpdate(dt)
    Lua_CommonUtil.removeTimer(self, self.checkHeartUpdate);
    if self.connectManager:isConnection(Connection.MAIN_SOCKET) ~= true then 
        GlobalVar.canReconnect = true;
        self.connectManager:errorAlert(LanUtil.getValue(10003), true);
        print("断线重连 serverprox.checkHeartUpdate");
    end
end

function Lua_LoginData:onServerUpdateEnd()
    if self.bLoadingVideoType then -- 未创角，播放动画进入场景
        self.bLoadingVideoType = false;
        self.videoSign = "LOGINLOADING";
        local showSkipBtnTime = Lua_CommonUtil.getCommonConfig("create_role_skip_time", 1);
        LuaUtil.showVideoLoadingScreenWin(self.videoSign, nil, "/video/loginvideo3.mp4", -1, -1, -1, -1, 5, 1, -1, true, true, showSkipBtnTime);
        showSkipBtnTime = showSkipBtnTime / 2;
        showSkipBtnTime = showSkipBtnTime < 5 and 5 or showSkipBtnTime;
        Lua_CommonUtil.delayCall(showSkipBtnTime, self, self.onCheckVideo);
        if DataCenter.mainData ~= nil then -- 提前初始化了
            self:parseServerPlayerInfoMsg();
        end
    else
        self:loadMainSec();
    end
end

function Lua_LoginData:clearChcekVideo()
    Lua_CommonUtil.removeTimer(self, self.onCheckVideo);
end

function Lua_LoginData:onCheckVideo()
    if not self.bShowVideoFrame then -- 第一帧还没显示
        Lua_WindowUtil.openWin("VideoLoadingScreenWindow", Lua_WinParam.ACTION_CLOSE);
        self.bShowVideoFrame = true;
        self.videoSign = nil;
        self:loadMainSec();
    end
end

function Lua_LoginData:loadMainSec()
    LuaManager.getInstance():loadLuaModule("main_sec", self, self.onMainSecLoaded);
end

function Lua_LoginData:onMainSecLoaded()
    if DataCenter ~= nil and DataCenter.mainData == nil then
        local data = checkRequire("Lua_MainData");
        DataCenter.mainData = data.new();
    end

    self:parseServerPlayerInfoMsg();
    self:onInit();
    self:loadSecConfig();
end

function Lua_LoginData:updatePlayerInfo(mp, isReconnect)
    if mp == nil then
        return;
    end
    self.serverPlayerInfoMsg = mp;

    if isReconnect then
        self:parseServerPlayerInfoMsg();
        self:onInit();
        self:onPreLoad();
        self:onEnteredInit();
        return;
    end

    if self.isUpdatePlayerInfo ~= true then
        self.isUpdatePlayerInfo = true;
        self.bStartLoadEnterGame = true;
        
        GlobalVar.bHandleServerMsg = false;
        GlobalVar.bShowLoadingWinBg = true;
        if LuaUtil.checkServerUpdate() then
            self:onServerUpdateEnd();
        end
    else
        self:parseServerPlayerInfoMsg();
    end
end

function Lua_LoginData:parseServerPlayerInfoMsg()
    if self.serverPlayerInfoMsg == nil then
        return;
    end

    local msg = ProtoPublic_pb.Proto80101001();
    msg:ParseFromString(self.serverPlayerInfoMsg.data);
    self.serverPlayerInfoMsg = nil;

    local t = tonumber(tostring(msg.time));
    DataCenter.roleData.serverTime = t;
    GlobalVar.cur_tick = msg.time;
    local roleId = tonumber(tostring(msg.show.id));
    GlobalVar.roleId = roleId;

    self.openServerDays = msg.open_days; -- 开服天数
    self.createRoleDays = msg.create_days; -- 创号天数
    local data = PlayerData.instance.data;
    data.exp = tonumber(tostring(msg.exp));
    local show = msg.show;
    data.roleId = roleId;
    data.nickname = show.name;
    data.gender = show.sex;
    data.career = show.career;
    data.lvl = show.level;
    data.vipLv = show.vip;
    data.fighting = show.force;
    data.area = show.area;
    data.agentCode = show.agent_code;
    data.serverFlag = show.server_flag;
    data.serverName = show.server_name;
    data.serverPrev = show.server_prev;
    data.league_id = show.league_id;
    data.league_pos = show.league_position;
    data.league_name = show.league_name;
    LightingMapManager.instance:init();

    -- lua部分更新
    DataCenter.mainLineData.checkpointId = msg.stage_id;
    Lua_ProxyManager.getProxy("Lua_RoleProxy"):updateRoleInfo(msg);-- 更新角色信息
    DataCenter.gameReported:UpdatePlayerInfo();
end

-- 本地进入游戏场景测试，构造服务端数据
function Lua_LoginData:enterLocalGame()

end

function Lua_LoginData:loadSecConfig()
    ConfigManager.getInstance():loadOtherConfig();
    -- Lua_WindowUtil.openWin("Lua_CreateRoleWindow", Lua_WinParam.ACTION_CLOSE);
    -- Lua_WindowUtil.openWin("Lua_CreateRoleAniShowWindow", Lua_WinParam.ACTION_CLOSE);
    -- Lua_WindowUtil.openWin("Lua_StartWindow", Lua_WinParam.ACTION_CLOSE);
    -- Lua_WindowUtil.openWin("Lua_LoginPhoneWindow", Lua_WinParam.ACTION_CLOSE);
    -- Lua_WindowUtil.openWin("Lua_LoginWindow", Lua_WinParam.ACTION_CLOSE);
    -- Lua_WindowUtil.openWin("Lua_ServerListWindow", Lua_WinParam.ACTION_CLOSE);
    -- Lua_WindowUtil.openWin("Lua_ServerSelectWindow", Lua_WinParam.ACTION_CLOSE);
    -- Lua_WindowUtil.openWin("LoginBgWindow", Lua_WinParam.ACTION_CLOSE);
end

-- 登录预加载资源
function Lua_LoginData:preLoadGameRes()
    self.bPreLoadComplete = false;
    DataCenter.preLoadData:enterGamePreLoad(self, self.onPreLoad);
end

function Lua_LoginData:onPreLoad()
    self.bPreLoadComplete = true;
    self:checkEnterGame();
end

function Lua_LoginData:checkEnterGame()
    print("preload complete", self.isCreateRole, self.bPreLoadComplete, self.bShowVideoFrame, self.isEnterGameWorld);
    if not self.bShowVideoFrame or not self.bPreLoadComplete then
        return;
    end

    DataCenter.guideData:checkPlayGuide();
    if not self.isCreateRole then -- 未触发引导及未创角则自动打开创角界面
        local guideVo = DataCenter.guideData.curGuideVo;
        if guideVo == nil or not guideVo.isCreateRoleGuide then -- 非创角引导
            Lua_WindowUtil.openWin("Lua_CreateRoleWindow", WinParam.ACTION_OPEN);
        end
    end

    local iconId = Lua_MenuViewDefine.ICON_MAINCITY;
    local iconVo = DataCenter.mainMenuData:getMenuIconVo(iconId);
    if iconVo ~= nil then
        if iconVo.operateType == 1 then -- 打开窗口
            if (strIsNullOrEmpty(iconVo.operateParam) or Lua_WindowUtil.isWinInitComplete(iconVo.operateParam)) then -- 初始完成
                self:completeEnterGame();
            else
                self.waitInitedWinName = iconVo.operateParam;
            end
        elseif iconVo.operateType == 3 then -- 打开场景
            local sceneId = iconVo.sceneId;
            if iconVo.iconId == Lua_MenuViewDefine.ICON_MAINLINE then
                sceneId = DataCenter.mainLineData.curSceneId;
            end

            if sceneId <= 0 or Scene3DManager.instance:isShowSceneRoot(sceneId, 0) then -- 已打开
                self:completeEnterGame();
            else
                self.waitShowScene = sceneId;
            end
        else -- 暂时
            self:completeEnterGame();
        end

        DataCenter.mainMenuData:clickIconEvent(iconVo, false);
    else
        self:completeEnterGame();
    end
end

-- 进入游戏
function Lua_LoginData:completeEnterGame()
    Lua_WindowUtil.openWin("LoadingScreenWindow", Lua_WinParam.ACTION_CLOSE);
    DataCenter.mainData:onFirstEnterGame(self.videoSign ~= nil);
    self.waitShowScene = nil;
    self.waitInitedWinName = nil;
    print("completeEnterGame");
    if self.videoSign ~= nil then -- 视频播放
        self.isEnterGameWorld = self.isCreateRole;
        MsgUtil.callFunc(EventsDefine.VIDEOLODING_SHOW_SKIP, self.videoSign);
    else -- 非视频播放进入
        self.isEnterGameWorld = true;
        self:onEnteredInit();
    end
end

-- 创角成功或加载窗口关闭后初始化
function Lua_LoginData:onEnteredInit()
    Lua_MsgUtil.callFunc("UPDATE_MAIN_MENU", Lua_MenuViewDefine.MEBULIST_ALL)
    DataCenter.chatData:playEnterBroadcast()
    if not DataCenter.guideData.isGuiding then
        DataCenter.popupWinManager:checkPopupWin();
    end
end

function Lua_LoginData.Get:isInGameWorld()
    return self.isEnterGameWorld and self.isCreateRole;
end