-- sdk接口
checkRequire("Lua_SDKMessageType");
local SDKInterface = SDKInterface;
Lua_SDKInterface = class("Lua_SDKInterface");
function Lua_SDKInterface:ctor()
	self:superCall("ctor");
	self:initEvents();
end

function Lua_SDKInterface:initEvents()
	MsgUtil.addEventListener(EventsDefine.SDK_MESSAGE_UPDATE, self, self.onSDKMessage); -- sdk通知
end

-- 调用sdk接口, dic为table
function Lua_SDKInterface:callSDKInterfaceTab(methobName, param)
	local paramJsonStr = nil;
	if param ~= nil then paramJsonStr = decodeTabToJson(param); end
	self:callSDKInterface(methobName, paramJsonStr)
end

-- 调用sdk接口, paramJsonStr为json格式
function Lua_SDKInterface:callSDKInterface(methobName, paramJsonStr)
	SDKInterface.CallSDKInterface(methobName, paramJsonStr);
end


-- sdk 通知，json格式
-- {"func":"标识","param":"参数集合"}
function Lua_SDKInterface:onSDKMessage(msg)
	if msg == nil or msg == "" then
		return;
	end

	local dic = decodeJson(msg);
    if dic == nil then
    	return;
    end

    local func = dic.func;
    local param = dic.param;
    if func == Lua_SDKMessageType.netState then -- 网络
    	SDKInfo.NetState = param.netState;
        if param.netState == Lua_SDKMessageType.NO_NET and GlobalVar.reconnect == 0 and GlobalVar.isInGame == 1 then
            GlobalVar.canReconnect = true;
            ConnectionManager.getInstace().errorAlert(LanUtil.getValue(10003), true);
        end
    elseif func == Lua_SDKMessageType.phoneinfo then -- 设备信息
    	self:setPhoneInfo(param);
    elseif func == Lua_SDKMessageType.login then -- 登陆成功返回给客户端
    	ServerConfig.userID = param.uid;
    	self.login_token = decodeTabToJson(param);
    	Lua_MsgUtil.callFunc("LOGIN_BACK_SEVER_SELECTED");
    elseif func == Lua_SDKMessageType.changeuser then -- 切换用户成功返回给客户端
	    ServerConfig.userID = param.uid;
    	self.login_token = decodeTabToJson(param);
        ConnectionManager.getInstace().loginOut();
    elseif func == Lua_SDKMessageType.logout then -- 注销
    	self.login_token = nil;
    	ServerConfig.userID = nil;
    	PlayerPrefsUtil.instance.dispose();
    	ConnectionManager.getInstace().loginOut();
    elseif func == Lua_SDKMessageType.netState then -- 上传图片
    	Lua_MsgUtil.callFunc("SELECT_FILE", param.imagepath);
    elseif func == Lua_SDKMessageType.ScreenHeight then -- 刘海高度
    	ServerConfig.sdkLiuhaiHight = param.ScreenHeight;
    elseif func == Lua_SDKMessageType.RunBackGround then --
    	MsgUtil.callFunc("STATE_RUNBACKGROUND_CHANGE", param.runState);
    end
end

function Lua_SDKInterface:setPhoneInfo(param)
	if param == nil then return; end
	SDKInfo.MACAddress = param.mac;
	SDKInfo.Imei = param.imei;
	SDKInfo.PhoneModel = param.sys_model;
	SDKInfo.SystemVersion = param.sys_version;
	SDKInfo.AvailMemory = param.avail_memory;
	SDKInfo.CustomDevice = param.custom_device;
	SDKInfo.openGL = param.openGl;
end

-- conf_id:1正常
-- money_type 1：人民币 2： 美金 3： 台币 4： 韩币 5： 越南币 6 ：新加坡币 7 ：泰株
function Lua_SDKInterface:PointOut(goldNum, money, money_type, conf_id, goodsName, diamondNum)
	if money_type == nil then money_type = 1; end
	if strIsNullOrEmpty(goodsName) or diamondNum == nil then
		local vo = Lua_RechargeConfigData.getRechargeConfig(conf_id);
		goodsName = vo.gift_name;
		diamondNum = vo.gold;
	end

	local tipsData = {
		goldNum = goldNum,
		money = money,
		money_type = money_type,
		conf_id = conf_id,
		goodsName = goodsName,
		diamondNum = diamondNum,
		des = LanUtil.formateStr(130023, tostring(money), goodsName),
		font_size = 28,
		posY = 30,
		btnType = 1,
		owner = self,
		sureFun = self.onPointOut
	};
	Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
end

function Lua_SDKInterface:onPointOut(param)
	local formData = {
		getOrderId = 1,
		server = ServerConfig.sign,
		package = tostring(ServerConfig.market),
		role_id = DataCenter.roleData.roleId,
		money = param.money,
		money_type = param.money_type,
		account = ServerConfig.userID,
		conf_id = param.conf_id,
		role_level = DataCenter.roleData.level,
		mac = ServerConfig.mac
	};
	if Lua_PlatformUtil.IsAndroid() then
		formData.imei = SDKInfo.Imei;
	elseif Lua_PlatformUtil.IsIPhonePlayer() then
		formData.idfa = SDKInfo.Idfa;
	end

	-- 获取订单号
	local tokenstr = decodeTabToJson(formData);
	formData.goodsName = param.goodsName;
	formData.diamondNum = param.diamondNum;
	local extParam = decodeTabToJson(formData);
	UploadManager.getInstance():uploadPhpPost(UrlManager.prefixRequestStr, tokenstr, extParam, self, self.loadServerComplete, self.loadServerError, true);
end

function Lua_SDKInterface:loadServerError(text, extParam)
    print("请求订单错误--", text, extParam);
end

function Lua_SDKInterface:loadServerComplete(text, extParam)
	if strIsNullOrEmpty(text) or strIsNullOrEmpty(extParam) then
		print("请求订单错误 text = nil", extParam);
		return;
	end

	local dictionary = decodeJson(text);
	if dictionary == nil then
		print("请求订单号text Json解析失败", text, extParam);
		return;
	end

	local error = dictionary.error;
    if not strIsNullOrEmpty(error) then
        print("请求订单号失败：", error, text, extParam);
        return;
    end

    local extParamDic = decodeJson(extParam);
    if extParamDic == nil then
    	print("请求订单号extParam Json解析失败", text, extParam);
    	return;
    end
    
    if Lua_PlatformUtil.IsAndroid() or Lua_PlatformUtil.IsIPhonePlayer() then
		if SDKInfo.IsNoSdk then
			self:testEditorRecharge(dictionary.orderId, extParamDic.money);
			return;
		end

		local formData = {};
    	formData.money = extParamDic.money;
    	formData.server = extParamDic.server;
    	formData.name = extParamDic.goodsName;
    	formData.gold = extParamDic.diamondNum;
    	formData.vip = DataCenter.roleData.vip;
    	formData.fighting = DataCenter.roleData.force;
		dictionary.myParam = formData;
		self:callSDKInterface(Lua_SDKMessageType.PointOut, decodeTabToJson(dictionary));
	else
		local linkUrl = dictionary.links;
        if not strIsNullOrEmpty(linkUrl) then -- 跳转
            UnityEngine.Application.OpenURL(linkUrl);
            return;
        end
        self:testEditorRecharge(dictionary.orderId, extParamDic.money);
    end
end

function Lua_SDKInterface:testEditorRecharge(orderId, rechargeNum)
    local url = UrlManager.FIX_HTTP .. ServerConfig.center_server .. "/single/charge/package/" .. ServerConfig.market .. "?extends=" .. orderId .. "|" .. ServerConfig.sign;
    LoadManager.getInstance():Load(Lua_LoadFileType.JSON, url, true);
    print("testEditorRecharge: ", url);
end